Documentation
¶
Index ¶
- Constants
- func Clean(configFile string, outputDir string) error
- func Run(configFile string, outputDir string) error
- type Command
- type Context
- func (c *Context) AppNamespace() string
- func (c *Context) Config() *e2econfig.Config
- func (c *Context) Context() context.Context
- func (c *Context) Deployer() types.Deployer
- func (c *Context) Env() *types.Env
- func (c *Context) Logger() *zap.SugaredLogger
- func (c *Context) ManagementNamespace() string
- func (c *Context) Name() string
- func (c Context) WithTimeout(d stdtime.Duration) (*Context, context.CancelFunc)
- func (c *Context) Workload() types.Workload
- type Report
- type Test
Constants ¶
const ( ValidateStep = "validate" SetupStep = "setup" TestsStep = "tests" CleanupStep = "cleanup" )
const ( Passed = report.SummaryKey("passed") Failed = report.SummaryKey("failed") Skipped = report.SummaryKey("skipped") Canceled = report.SummaryKey("canceled") )
Summary keys for test reports.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Command ¶
type Command struct {
// contains filtered or unexported fields
}
Command is a ramenctl test command.
func (*Command) Clean ¶ added in v0.5.0
Clean up after running a test flow and return an if cleaning one or more tests failed.
func (*Command) Logger ¶ added in v0.8.0
func (c *Command) Logger() *zap.SugaredLogger
type Context ¶
type Context struct {
// contains filtered or unexported fields
}
Context implements types.TestContext interface.
func (*Context) AppNamespace ¶
func (*Context) Logger ¶
func (c *Context) Logger() *zap.SugaredLogger
func (*Context) ManagementNamespace ¶
func (Context) WithTimeout ¶ added in v0.6.0
WithTimeout returns a derived context with a deadline. Call cancel to release resources associated with the context as soon as the operation running in the context complete.
type Report ¶ added in v0.1.1
Report created by test sub commands.
Click to show internal directories.
Click to hide internal directories.